@@ -33,7 +33,7 @@ class TaskManagerPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
     public:
-        virtual void registerTypes(const char *uri);
+        void registerTypes(const char *uri) Q_DECL_OVERRIDE;
 };
 
 }
