@@ -20,8 +20,8 @@
 #define DESKTOVIEW_H
 
 
-#include "plasmaquick/containmentview.h"
-#include "panelconfigview.h"
+#include <PlasmaQuick/ContainmentView>
+#include <PlasmaQuick/ConfigView>
 #include <QtCore/qpointer.h>
 
 namespace KWayland
@@ -88,14 +88,12 @@ private Q_SLOTS:
 Q_SIGNALS:
     void stayBehindChanged();
     void windowTypeChanged();
-    void screenRenamed();
 
 private:
     void coronaPackageChanged(const KPackage::Package &package);
     void ensureWindowType();
     void setupWaylandIntegration();
 
-    QString m_screenName;
     QPointer<PlasmaQuick::ConfigView> m_configView;
     QPointer<QScreen> m_oldScreen;
     QPointer<QScreen> m_screenToFollow;
